==> php54-owncloud-8.0.2.tgz: share/owncloud/apps/files_sharing/l10n/hu_HU.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "A kiszolgálók közötti megosztás nincs engedélyezve ezen a kiszolgálón",
    "The mountpoint name contains invalid characters." : "A csatlakozási pont neve érvénytelen karaktereket tartalmaz ",
    "Invalid or untrusted SSL certificate" : "Érvénytelen vagy nem megbízható az SSL tanúsítvány",
    "Couldn't add remote share" : "A távoli megosztás nem hozható létre",
    "Shared with you" : "Velem osztották meg",
    "Shared with others" : "Én osztottam meg másokkal",
    "Shared by link" : "Linkkel osztottam meg",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Használatba kívánja venni a {name} távoli megosztást, amit a {owner}@{remote} címről kapott?",
    "Remote share" : "Távoli megosztás",
    "Remote share password" : "Jelszó a távoli megosztáshoz",
    "Cancel" : "Mégsem",
    "Add remote share" : "Távoli megosztás létrehozása",
    "Invalid ownCloud url" : "Érvénytelen ownCloud webcím",
    "Share" : "Megosztás",
    "Shared by" : "Megosztotta Önnel",
    "This share is password-protected" : "Ez egy jelszóval védett megosztás",
    "The password is wrong. Try again." : "A megadott jelszó nem megfelelő. Próbálja újra!",
    "Password" : "Jelszó",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a könyvtárban",
    "Name" : "Név",
    "Share time" : "A megosztás időpontja",
    "Sorry, this link doesn’t seem to work anymore." : "Sajnos úgy tűnik, ez a link már nem működik.",
    "Reasons might be:" : "Ennek az oka a következő lehet:",
    "the item was removed" : "az állományt időközben eltávolították",
    "the link expired" : "lejárt a link érvényességi ideje",
    "sharing is disabled" : "letiltásra került a megosztás",
    "For more info, please ask the person who sent this link." : "További információért forduljon ahhoz, aki ezt a linket küldte Önnek!",
    "Add to your ownCloud" : "Adjuk hozzá a saját ownCloudunkhoz",
    "Download" : "Letöltés",
    "Download %s" : "%s letöltése",
    "Direct link" : "Közvetlen link"
},
"nplurals=2; plural=(n != 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files_sharing/l10n/hu_HU.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "A kiszolgálók közötti megosztás nincs engedélyezve ezen a kiszolgálón",
    "The mountpoint name contains invalid characters." : "A csatlakozási pont neve érvénytelen karaktereket tartalmaz ",
    "Invalid or untrusted SSL certificate" : "Érvénytelen vagy nem megbízható az SSL tanúsítvány",
    "Couldn't add remote share" : "A távoli megosztás nem hozható létre",
    "Shared with you" : "Velem osztották meg",
    "Shared with others" : "Én osztottam meg másokkal",
    "Shared by link" : "Linkkel osztottam meg",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Használatba kívánja venni a {name} távoli megosztást, amit a {owner}@{remote} címről kapott?",
    "Remote share" : "Távoli megosztás",
    "Remote share password" : "Jelszó a távoli megosztáshoz",
    "Cancel" : "Mégsem",
    "Add remote share" : "Távoli megosztás létrehozása",
    "Invalid ownCloud url" : "Érvénytelen ownCloud webcím",
    "Share" : "Megosztás",
    "Shared by" : "Megosztotta Önnel",
    "A file or folder has been <strong>shared</strong>" : "Fájl vagy könyvtár <strong>megosztása</strong>",
    "You shared %1$s with %2$s" : "%1$s-t megosztottam ővele: %2$s",
    "You shared %1$s with group %2$s" : "%1$s-t megosztottam ezzel a csoporttal: %2$s",
    "%2$s shared %1$s with you" : "%2$s megosztotta velem ezt: %1$s",
    "You shared %1$s via link" : "Megosztottam link segítségével: %1$s",
    "Shares" : "Megosztások",
    "This share is password-protected" : "Ez egy jelszóval védett megosztás",
    "The password is wrong. Try again." : "A megadott jelszó nem megfelelő. Próbálja újra!",
    "Password" : "Jelszó",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a könyvtárban",
    "Name" : "Név",
    "Share time" : "A megosztás időpontja",
    "Sorry, this link doesn’t seem to work anymore." : "Sajnos úgy tűnik, ez a link már nem működik.",
    "Reasons might be:" : "Ennek az oka a következő lehet:",
    "the item was removed" : "az állományt időközben eltávolították",
    "the link expired" : "lejárt a link érvényességi ideje",
    "sharing is disabled" : "letiltásra került a megosztás",
    "For more info, please ask the person who sent this link." : "További információért forduljon ahhoz, aki ezt a linket küldte Önnek!",
    "Add to your ownCloud" : "Adjuk hozzá a saját ownCloudunkhoz",
    "Download" : "Letöltés",
    "Download %s" : "%s letöltése",
    "Direct link" : "Közvetlen link"
},
"nplurals=2; plural=(n != 1);");
